@@ -13,3 +13,10 @@ def setup_log(level=logging.DEBUG, handlers: List[logging.Handler] = None) -> No
 
 def get_format() -> logging.Formatter:
     return logging.Formatter('[%(asctime)s] [%(levelname)s] [%(name)s:%(funcName)s] - %(message)s')
+
+
+def get_json_format() -> logging.Formatter:
+    return logging.Formatter(
+        "{'time':'%(asctime)s', 'name': '%(name)s', 'func': '%(funcName)s', 'level': '%(levelname)s', "
+        "'message': '%(message)s'}"
+    )
